# -*- coding: utf-8 -*
from __future__ import print_function
import numpy as np 
import cv2
import pandas as pd

	# Panel 检测 【方案一】

	# 1.检测非深海景深物体 
	# 当camera前方有非深海景深物体出现时（海底，或者目标结构）
	# 灯光被物体反射，会导致灰度图（或者说V通道），像素值升高（变白）
	# 那么，就让ROV向此处靠近，同时启动 SLAM 实时计算与物体之间的深度信息，防止意外碰撞
	# 此外还要启动 color_based detection 如果黄色区域出现，则认为 panel出现，或者是其他 黄色的人造物

	# # 这项待定
	# # 2.黄颜色
	# # HSVcolor based detection 
	# panel_color = cv2.inRange(HSVframe,panel_Lower, panel_Upper)
	# # # 距离较近的时候，或者近处的 panel 结构容易被识别出来。远距离，或者远处的 panel 结构很可能识别不出来。
	# # 或者panel上灰尘比较多，或者附着物比较多时，基于颜色就不能识别出了，甚至怀疑，基于学习的岂不是目标也发生了变化？
	# # 那么基于大量panel资料的学习是否也没有意义呢？这一点暂时不能下定论，只是存疑。
	# # 针对这个case，我想到的解决方案是：是否可以尝试结合 v-s 图像和检测深度的突变，深海背景处的深度信息突然变化后，是否表示有结构突然出现


	# 1.出现图像，表示出现前景物体。 2.出现图像，说明有黄色区域出现，因为海洋背景以蓝绿色为主，所以黄色不会受背景影响
	# 当1.2.同时出现图像，说明出现了黄颜色的前景，有可能就是 panel

######################################################################################################


def PanelDetect(chans,mask,erode_kernel,imshow = 1):

	# 1.非深海景深 == 反光前景	
	# 当camera中出前景时，其与背景会使 V-channel 的 直方图形成两个峰值，这种情况下，可以使用大津算法
	# 自适应的计算阈值，通过二值化，高亮前景
	(ret,th) = cv2.threshold(chans[2],0,255,cv2.THRESH_BINARY+cv2.THRESH_OTSU)
	th = cv2.bitwise_and(th,th,mask = mask)
	(M1,N1) = th.shape
	thpd = th.reshape(M1*N1, -1)
	thdf = pd.DataFrame(thpd)
	m1 = thdf.max()
	print("m1",m1)

	# 2.黄色检测
	# panel_Lower = np.array([15,0,0])#([15,80,120])#panel_Upper = np.array([50,256,256])
	panel_color = cv2.inRange(chans[0],15, 50)
	panel_color = cv2.bitwise_and(panel_color,panel_color,mask = mask)
	# 小块去除
	panel_color = cv2.erode(panel_color,erode_kernel)
	(M2,N2) = panel_color.shape
	pcpd = panel_color.reshape(M2*N2, -1)
	pcdf = pd.DataFrame(pcpd)
	m2 = pcdf.max()
	print("m2",m2)


	# 初始值
	inf = None
	ik = [0,0]

	# ik = 1 SLAM + mani
	# ik = 2 SLAM
	# ik = 3 OA?
	if m1.ix[[0][0]] == 255:
		if m2.ix[[0][0]] == 255:
			inf = "Panel find !"
			ik = [1,1]	
		else:
			inf = "####  WARNING  ####    --- Seabed or other foreground"
			ik = [1,0]
	if m1.ix[[0][0]] == 0:
		if m2.ix[[0][0]] == 255:
			inf = "####  WARNING  ####    --- Color  detect"
			ik = [0,1]
		else:
			inf = "####  WARNING  ####    --- Ocean background"
			ik = [0,0]

	# 显示结果
	if imshow == 1:
		cv2.imshow("Non-ocean background",th)
		cv2.imshow("color_based detect",panel_color)

 	return (inf,ik)